from setuptools import setup

setup(name='JagsGaus',
      version='1.3',
      description='Gaussian distributions',
      packages=['JagsGaus'],
      author= 'Jagriti Prakash' ,
      zip_safe=False)
